@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2003 Gentoo Technologies, Inc.
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/livecd-functions.sh,v 1.2 2004/04/07 16:44:00 agriffis Exp $
+# $Header: /home/cvsroot/gentoo-src/rc-scripts/sbin/livecd-functions.sh,v 1.4 2004/04/08 22:09:46 agriffis Exp $
 
 # Global Variables:
 #    CDBOOT			-- is booting off CD
@@ -162,7 +162,7 @@ livecd_fix_inittab() {
 			echo "c${x}:12345:respawn:/sbin/mingetty --noclear --autologin root tty${x}" >> /etc/inittab
 		done	
 	else
-		echo "c1:12345:respawn:/sbin/agetty ${LIVECD_CONSOLE_BAUD} ${LIVECD_CONSOLE} linux" >> /etc/inittab
+		echo "c1:12345:respawn:/sbin/agetty -nl /bin/bash ${LIVECD_CONSOLE_BAUD} ${LIVECD_CONSOLE} vt100" >> /etc/inittab
 	fi
 	return 0
 }
